@@ -8,7 +8,7 @@ class SinglyLinkedListAlgorithm:
         self.data_name = data_name
         self.next_name = next_name
 
-    def reverse_print(node, head):
+    def reverse_print(self, node, head):
         if not node:
             print(f"{node} <- ", end="")
         self.reverse_print(node.__dict__[self.next_name])
@@ -18,6 +18,7 @@ class SinglyLinkedListAlgorithm:
             print(f"{node.__dict__[self.data_name]} <- ", end="")
 
     def reverse(self, previous, current):
+        """ head = reverse(head, head.next) """
         if current:
             head = self.reverse(current, current.__dict__[self.next_name])
             current.__dict__[self.next_name] = previous
